@@ -106,7 +106,9 @@ def create_handler(app):
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
             print("Lambda is warm!")
             return {}
-
+        print('context', context)
+        print('contect_dict', context.__dict__)
+        print('sls sdk', context.serverless_sdk)
         asgi_handler = Mangum(app, api_gateway_base_path=g.settings.stage)
         response = asgi_handler(event, context)
         return response
